@@ -497,6 +497,11 @@ class Progress(Base):
     subject_id = Column(ForeignKey('univer_subject.subject_id'))
     subject = relationship('Subject')
 
+    # Наименование дисциплины
+    subject_name_ru = Column(String(500))
+    subject_name_kz = Column(String(500))
+    subject_name_en = Column(String(500))
+
     # Тип оценки
     mark_type_id = Column(ForeignKey('univer_mark_type.mark_type_id'))
     mark_type = relationship('MarkType')
@@ -523,4 +528,24 @@ class Progress(Base):
         return '<Progress {}>'.format(self)
     
     def __str__(self):
-        return '{} - {}'.format(self.student, self.subject)
\ No newline at end of file
+        return '{} - {}'.format(self.student, self.subject)
+
+
+class Country(Base):
+    __tablename__ = 'univer_country'
+
+    id = Column('country_id', Integer, primary_key=True)
+    status = Column(Integer)
+    name_ru = Column('country_name_ru', String(500))
+    name_kz = Column('country_name_kz', String(500))
+    name_en = Column('country_name_en', String(500))
+    code = Column('country_code', Integer)
+    current = Column('country_current', Integer)
+    letter_code = Column('country_letter_code', String(10))
+    alfa3_code = Column(String(5))
+
+    def __repr__(self):
+        return '<Country {}>'.format(self)
+    
+    def __str__(self):
+        return self.name_ru
\ No newline at end of file
