@@ -88,6 +88,8 @@ class Student(Base):
     # Пол
     sex = Column('students_sex', Integer)
 
+    marital_status = Column('students_marital_status', Integer)
+
     # Дата рождения
     birth_date = Column('students_birth_date', DateTime)
 
@@ -146,6 +148,10 @@ class Student(Base):
     # Год начала действия учебного плана
     educ_plan_adm_year = Column(Integer)
 
+    # Языковое отделение
+    lang_division_id = Column(ForeignKey('univer_lang_division.lang_division_id'))
+    lang_division = relationship('LangDivision')
+
     @property
     def payment_info_ru(self):
         if self.payment_form_id == 2:
